package types
import "github.com/rticommunity/rticonnextdds-connector-go/types"
Index ¶
Types ¶
type Position ¶
Position is a position struct for shapes
type Shape ¶
type Shape struct {
Color string `json:"color"`
X int `json:"x"`
Y int `json:"y"`
Shapesize int `json:"shapesize"`
}
Shape is a struct parsed from the data type for RTI shapes demo
type ShapeArray ¶
type ShapeArray struct {
Color string `json:"color"`
X [100]int `json:"x"`
Y [100]int `json:"y"`
Shapesize int `json:"shapesize"`
}
ShapeArray is a shape struct with arrays
type ShapeModule ¶
type ShapeModule struct {
Color string `json:"color"`
Pos Position `json:"pos"`
Shapesize int `json:"shapesize"`
}
ShapeModule is a shape struct including another struct (Position)
type ShapeSlice ¶
type ShapeSlice struct {
Color string `json:"color"`
X []int `json:"x"`
Y []int `json:"y"`
Shapesize int `json:"shapesize"`
}
ShapeSlice is a shape struct with slices
type Test ¶
type Test struct {
St string `json:"st"`
B bool `json:"b"`
C uint8 `json:"c"`
Xs int8 `json:"xs"`
S int16 `json:"s"`
Us uint16 `json:"us"`
L int32 `json:"l"`
Ul uint32 `json:"ul"`
Ll int64 `json:"ll"`
Ull uint64 `json:"ull"`
F float32 `json:"f"`
D float64 `json:"d"`
}
Test is the struct for testing
Source Files ¶
- Version
- v1.3.4 (latest)
- Published
- Sep 24, 2025
- Platform
- linux/amd64
- Last checked
- 7 months ago –
Tools for package owners.